DingtalkSdk class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
dingtalkResponseEventHandler
→ Stream<
BaseResponse> -
no setter
Static Methods
-
isDingtalkInstalled(
) → Future< bool?> -
registerAppWithIdentifierForOrgApp(
{required String appId, required String bundleId}) → Future< bool?> -
sendAuthForOrgApp(
{required String redirectUrl, String responseType = 'code', String scope = 'openid', String prompt = 'consent', String state = '', String nonce = ''}) → Future< bool?>